@@ -18,6 +18,8 @@ def ImageSizeVocabulary(context):
     portal_properties = getToolByName(site, 'portal_properties', None)
     if 'imaging_properties' in portal_properties.objectIds():
         sizes = portal_properties.imaging_properties.getProperty('allowed_sizes')
+        sizes += ('none',)
+        # sizes.append('none')
         terms = [ SimpleTerm(value=format_size(pair), token=format_size(pair), title=pair) for pair in sizes ]
         return SimpleVocabulary(terms)
     else:
